/*****************************************************************
*Barometre et Thermomètre sur prise secteur avec afficheur sur 
*écran TFT avec indication des pressions mini et maxi enregistrées. 
*Une sonde BMP280 ; un Arduino Nano; une alimentation à découpage
*de 5volt et un ecran 0,96'
*B.LECLERC http://amazing-vacuum-tubes@e-monsite.com 
*****************************************************************/

#include "BMP280.h" //Declaration de la sonde et de ses librairies
#define P0 1015.25   //Correction en fonction de l'altitude

#include <Adafruit_SSD1306.h> // Utilisation de la Library Gestion Afficheur
#define OLED_RESET 4 // Reset pin # 
Adafruit_SSD1306 display(OLED_RESET);  //définition de la séquence d'affichage

#include <EEPROM.h>  //Declaration de l'EEPROM et de ses librairies 
#include <avr/pgmspace.h>  //Organisation de l'espace mémoire

#define RstBut 2

BMP280 bmp;
float Tmin,Tmax,Pmin,Pmax,Tprevious,Pprevious; //  Decleration des variables utilisees ...
byte progress = 0; 


void setup()
{
 
  EEPROM.get(5, Pmin); // lecture et affectation dela pression mini dans la case 5
  EEPROM.get(10, Pmax);  // lecture et affectation dela pression mini dans la case 5

pinMode (RstBut, INPUT_PULLUP);
   
  if(!bmp.begin()){ // Démarage BMP260 
    while(1);       // Et tourne toujours ........
  }
  
  
bmp.setOversampling(4);  // 0 à 4, les nombres les plus élevés correspondent aux sorties plus lentes et aux résolutions plus élevées

display.begin(SSD1306_SWITCHCAPVCC, 0x3C);  // Initialisation de l'afficheur et son adresse I2C 

if (digitalRead (RstBut)== LOW) {  // Remise à des valeurs volontairement irréalistes de la EEprom si le bouton est appuyé au boot RAZ !
  Pmin = 1055;
    Pmax = 800;
    EEPROM.put(5, Pmin);  // dans la case 5
  EEPROM.put(10, Pmax); // dans la case 10
}

}



void loop()
{
  double T,P;  //température & pression
  char result = bmp.startMeasurment(); // début de mesure....
 
    if(result!=0){   //Si le résultat n'est pas nul ...
    delay(result);
    result = bmp.getTemperatureAndPressure(T,P);

display.display();  // initialisation d'une séquence d'affichage 
display.clearDisplay(); // Effacement des écrits précédents 
display.setTextSize(1);  // Choix de la taille des caractères 
display.setTextColor(WHITE); // Choix de la couleur des caractères 
display.setCursor(1,0); // Position curseur 
display.print("Temp: ");display.print(T - 1,1); display.print(" degC"); // affichage sur la 1°ligne, sur 1 décimale, avec la correction de l'écart de la sonde ...
display.setCursor(1,11);  // Position curseur
display.print("Pression: ");display.print(P + 39,0); display.print(" hPa"); // affichage sur la 1°ligne, sur 1 décimale, avec la correction de l'écart de la sonde ...
display.setCursor(1,20);  // Position curseur
display.print("Min:");display.print(Pmin + 39,0); display.print(" Max:");display.print(Pmax + 39,0);
display.setTextSize(1);  // Choix de la taille des caractères 
display.setCursor(115,20);  // Position curseur
display.print (char(progress));  //Affiche la flèche sur la 14 ème case 2ème ligne                      

       

              
       if (P > (Pprevious + 1)){ //Si la pression monte de 1 hPa  ...
         progress = 65;
         Pprevious = P;  //Réactualisation de la nouvelle valeur
         }
         
      if (P < (Pprevious - 1)){ //Si la pression descent de 1 hPa  ...
          progress = 68;
         Pprevious = P;  //Réactualisation de la nouvelle valeur
         }
      if (P<Pmin) //a stocker en EEprom, si la valeur est inférieure à la précédente valeur mini
         {Pmin=P;  //Réactualisation de la nouvelle valeur
         EEPROM.put(5, Pmin);  // dans la case 5
         }
      if (P>Pmax)  //a stocker en EEprom, si la valeur est superieure à la précédente valeur maxi
         {Pmax=P;  //Réactualisation de la nouvelle valeur
         EEPROM.put(10, Pmax); // dans la case 10
         }
   }
    
delay (500);


}
 
